@@ -1,10 +1,7 @@
 package analyser
 
 import (
-	"reflect"
-
 	resourceaws "github.com/cloudskiff/driftctl/pkg/resource/aws"
-
 	"github.com/r3labs/diff/v2"
 
 	"github.com/cloudskiff/driftctl/pkg/alerter"
@@ -32,7 +29,7 @@ func NewComputedDiffAlert() *ComputedDiffAlert {
 }
 
 func (c *ComputedDiffAlert) Message() string {
-	return "You have diffs on computed fields, check the documentation for potential false positive drifts"
+	return "You have diffs on computed fields, check the documentation for potential false positive drifts: https://docs.driftctl.com/limitations"
 }
 
 func (c *ComputedDiffAlert) ShouldIgnoreResource() bool {
@@ -81,7 +78,8 @@ func (a Analyzer) Analyze(remoteResources, resourcesFromState []resource.Resourc
 		filteredRemoteResource = removeResourceByIndex(i, filteredRemoteResource)
 		analysis.AddManaged(stateRes)
 
-		delta, _ := diff.Diff(stateRes, remoteRes)
+		var delta diff.Changelog
+		delta, _ = diff.Diff(stateRes.Attributes(), remoteRes.Attributes())
 
 		if len(delta) == 0 {
 			continue
@@ -93,7 +91,11 @@ func (a Analyzer) Analyze(remoteResources, resourcesFromState []resource.Resourc
 				continue
 			}
 			c := Change{Change: change}
-			c.Computed = a.isComputedField(stateRes, c)
+			resSchema := stateRes.Schema()
+			if resSchema != nil {
+				c.Computed = resSchema.IsComputedField(c.Path)
+				c.JsonString = resSchema.IsJsonStringField(c.Path)
+			}
 			if c.Computed {
 				haveComputedDiff = true
 			}
@@ -143,47 +145,6 @@ func removeResourceByIndex(i int, resources []resource.Resource) []resource.Reso
 	return append(resources[:i], resources[i+1:]...)
 }
 
-// isComputedField returns true if the field that generated the diff of a resource
-// has a computed tag
-func (a Analyzer) isComputedField(stateRes resource.Resource, change Change) bool {
-	if field, ok := a.getField(reflect.TypeOf(stateRes), change.Path); ok {
-		return field.Tag.Get("computed") == "true"
-	}
-	return false
-}
-
-// getField recursively finds the deepest field inside a resource depending on
-// its path and its type
-func (a Analyzer) getField(t reflect.Type, path []string) (reflect.StructField, bool) {
-	switch t.Kind() {
-	case reflect.Ptr:
-		return a.getField(t.Elem(), path)
-	case reflect.Slice:
-		return a.getField(t.Elem(), path[1:])
-	default:
-		{
-			if field, ok := t.FieldByName(path[0]); ok && a.hasNestedFields(field.Type) && len(path) > 1 {
-				return a.getField(field.Type, path[1:])
-			} else {
-				return field, ok
-			}
-		}
-	}
-}
-
-// hasNestedFields will return true if the current field is either a struct
-// or a slice of struct
-func (a Analyzer) hasNestedFields(t reflect.Type) bool {
-	switch t.Kind() {
-	case reflect.Ptr:
-		return a.hasNestedFields(t.Elem())
-	case reflect.Slice:
-		return t.Elem().Kind() == reflect.Struct
-	default:
-		return t.Kind() == reflect.Struct
-	}
-}
-
 // hasUnmanagedSecurityGroupRules returns true if we find at least one unmanaged
 // security group rule
 func (a Analyzer) hasUnmanagedSecurityGroupRules(unmanagedResources []resource.Resource) bool {
