@@ -4,10 +4,13 @@ import (
 	"fmt"
 	"os"
 	"os/signal"
+	"regexp"
 	"strings"
 	"syscall"
 
 	"github.com/cloudskiff/driftctl/pkg/telemetry"
+	"github.com/fatih/color"
+	"github.com/mitchellh/go-homedir"
 	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
@@ -75,9 +78,17 @@ func NewScanCmd() *cobra.Command {
 				opts.Filter = expr
 			}
 
+			providerVersion, _ := cmd.Flags().GetString("tf-provider-version")
+			if err := validateTfProviderVersionString(providerVersion); err != nil {
+				return err
+			}
+			opts.ProviderVersion = providerVersion
+
 			opts.Quiet, _ = cmd.Flags().GetBool("quiet")
 			opts.DisableTelemetry, _ = cmd.Flags().GetBool("disable-telemetry")
 
+			opts.ConfigDir, _ = cmd.Flags().GetString("config-dir")
+
 			return nil
 		},
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -136,11 +147,31 @@ func NewScanCmd() *cobra.Command {
 		"Terraform Cloud / Enterprise API token.\n"+
 			"Only used with tfstate+tfcloud backend.\n",
 	)
+	fl.String(
+		"tf-provider-version",
+		"",
+		"Terraform provider version to use.\n",
+	)
 	fl.BoolVar(&opts.StrictMode,
 		"strict",
 		false,
 		"Includes cloud provider service-linked roles (disabled by default)",
 	)
+	fl.StringVar(&opts.DriftignorePath,
+		"driftignore",
+		".driftignore",
+		"Path to the driftignore file",
+	)
+
+	configDir, err := homedir.Dir()
+	if err != nil {
+		configDir = os.TempDir()
+	}
+	fl.String(
+		"config-dir",
+		configDir,
+		"Directory path that driftctl uses for configuration.\n",
+	)
 
 	return cmd
 }
@@ -156,9 +187,13 @@ func scanRun(opts *pkg.ScanOptions) error {
 	supplierLibrary := resource.NewSupplierLibrary()
 
 	iacProgress := globaloutput.NewProgress("Scanning states", "Scanned states", true)
-	scanProgress := globaloutput.NewProgress("Scanning resources", "Scanned resources", true)
+	scanProgress := globaloutput.NewProgress("Scanning resources", "Scanned resources", false)
 
-	err := remote.Activate(opts.To, alerter, providerLibrary, supplierLibrary, scanProgress)
+	resourceSchemaRepository := resource.NewSchemaRepository()
+
+	resFactory := terraform.NewTerraformResourceFactory(resourceSchemaRepository)
+
+	err := remote.Activate(opts.To, opts.ProviderVersion, alerter, providerLibrary, supplierLibrary, scanProgress, resourceSchemaRepository, resFactory, opts.ConfigDir)
 	if err != nil {
 		return err
 	}
@@ -172,14 +207,12 @@ func scanRun(opts *pkg.ScanOptions) error {
 
 	scanner := pkg.NewScanner(supplierLibrary.Suppliers(), alerter)
 
-	iacSupplier, err := supplier.GetIACSupplier(opts.From, providerLibrary, opts.BackendOptions, iacProgress)
+	iacSupplier, err := supplier.GetIACSupplier(opts.From, providerLibrary, opts.BackendOptions, iacProgress, resFactory)
 	if err != nil {
 		return err
 	}
 
-	resFactory := terraform.NewTerraformResourceFactory(providerLibrary)
-
-	ctl := pkg.NewDriftCTL(scanner, iacSupplier, alerter, resFactory, opts, scanProgress, iacProgress)
+	ctl := pkg.NewDriftCTL(scanner, iacSupplier, alerter, resFactory, opts, scanProgress, iacProgress, resourceSchemaRepository)
 
 	go func() {
 		<-c
@@ -201,6 +234,8 @@ func scanRun(opts *pkg.ScanOptions) error {
 		telemetry.SendTelemetry(analysis)
 	}
 
+	globaloutput.Printf(color.WhiteString("Provider version used to scan: %s. Use --tf-provider-version to use another version.\n"), resourceSchemaRepository.ProviderVersion.String())
+
 	if !analysis.IsSync() {
 		globaloutput.Printf("\nHint: use gen-driftignore command to generate a .driftignore file based on your drifts\n")
 
@@ -339,3 +374,13 @@ func parseOutputFlag(out string) (*output.OutputConfig, error) {
 		Options: options,
 	}, nil
 }
+
+func validateTfProviderVersionString(version string) error {
+	if version == "" {
+		return nil
+	}
+	if match, _ := regexp.MatchString("^\\d+\\.\\d+\\.\\d+$", version); !match {
+		return errors.Errorf("Invalid version argument %s, expected a valid semver string (e.g. 2.13.4)", version)
+	}
+	return nil
+}
