@@ -18,8 +18,9 @@ import (
 func TestAcc_AwsECRRepository(t *testing.T) {
 	var mutatedRepositoryID string
 	acceptance.Run(t, acceptance.AccTestCase{
-		Paths: []string{"./testdata/acc/aws_ecr_repository"},
-		Args:  []string{"scan", "--filter", "Type=='aws_ecr_repository'"},
+		TerraformVersion: "0.14.9",
+		Paths:            []string{"./testdata/acc/aws_ecr_repository"},
+		Args:             []string{"scan", "--filter", "Type=='aws_ecr_repository'"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
@@ -64,7 +65,7 @@ func TestAcc_AwsECRRepository(t *testing.T) {
 						analyser.Change{
 							Change: diff.Change{
 								Type: diff.UPDATE,
-								Path: []string{"ImageTagMutability"},
+								Path: []string{"image_tag_mutability"},
 								From: "MUTABLE",
 								To:   "IMMUTABLE",
 							},
