@@ -9,8 +9,9 @@ import (
 
 func TestAcc_AwsInternetGateway(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
-		Paths: []string{"./testdata/acc/aws_internet_gateway"},
-		Args:  []string{"scan", "--filter", "Type=='aws_internet_gateway'"},
+		TerraformVersion: "0.14.9",
+		Paths:            []string{"./testdata/acc/aws_internet_gateway"},
+		Args:             []string{"scan", "--filter", "Type=='aws_internet_gateway'"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
@@ -21,7 +22,7 @@ func TestAcc_AwsInternetGateway(t *testing.T) {
 						t.Fatal(err)
 					}
 					result.AssertInfrastructureIsInSync()
-					result.Equal(1, result.Summary().TotalManaged)
+					result.AssertManagedCount(1)
 				},
 			},
 		},
