@@ -5,6 +5,7 @@ import (
 	"time"
 
 	"github.com/cloudskiff/driftctl/pkg/remote/aws/repository"
+	"github.com/cloudskiff/driftctl/pkg/remote/cache"
 	"github.com/cloudskiff/driftctl/test"
 	"github.com/cloudskiff/driftctl/test/acceptance"
 	"github.com/cloudskiff/driftctl/test/acceptance/awsutils"
@@ -13,8 +14,9 @@ import (
 
 func TestAcc_AwsSNSTopicPolicy(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
-		Paths: []string{"./testdata/acc/aws_sns_topic_policy"},
-		Args:  []string{"scan", "--filter", "Type=='aws_sns_topic' || Type=='aws_sns_topic_policy'"},
+		TerraformVersion: "0.14.9",
+		Paths:            []string{"./testdata/acc/aws_sns_topic_policy"},
+		Args:             []string{"scan", "--filter", "Type=='aws_sns_topic' || Type=='aws_sns_topic_policy'"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
@@ -22,7 +24,7 @@ func TestAcc_AwsSNSTopicPolicy(t *testing.T) {
 				},
 				PreExec: func() {
 					err := acceptance.RetryFor(60*time.Second, func(doneCh chan struct{}) error {
-						client := repository.NewSNSClient(awsutils.Session())
+						client := repository.NewSNSClient(awsutils.Session(), cache.New(0))
 						topics, err := client.ListAllTopics()
 						if err != nil {
 							logrus.Warnf("Cannot list topics: %+v", err)
@@ -41,8 +43,7 @@ func TestAcc_AwsSNSTopicPolicy(t *testing.T) {
 					if err != nil {
 						t.Fatal(err)
 					}
-					result.AssertDriftCountTotal(0)
-					result.AssertDeletedCount(0)
+					result.AssertInfrastructureIsInSync()
 					result.AssertManagedCount(6)
 				},
 			},
